@@ -51,18 +51,39 @@ class ActiveLearningDataset(torchdata.Dataset):
         if pool_specifics is None:
             pool_specifics = {}
         if eval_transform is not None:
-            warnings.warn(f"""eval_transform is deprecated and will be removed shortly.
+            warnings.warn("""eval_transform is deprecated and will be removed shortly.
             Please update your constructor to use
-             `pool_specifics={{'transform': {{eval_transform}}}}`""", DeprecationWarning)
+             `pool_specifics={{'transform': {}}}`""".format(eval_transform), DeprecationWarning)
             pool_specifics['transform'] = eval_transform
         self.pool_specifics = pool_specifics
 
         self.make_unlabelled = make_unlabelled
         # For example, FileDataset has a method 'label'. This is useful when we're in prod.
-        self.can_label = hasattr(self._dataset, 'label')
+        self.can_label = self.check_dataset_can_label()
 
         self.random_state = check_random_state(random_state)
 
+    def check_dataset_can_label(self):
+        """Check if a dataset can be labelled.
+
+        Returns:
+            Whether the dataset's label can be modified or not.
+
+        Notes:
+            To be labelled, a dataset needs a method `label`
+            with definition: `label(self, idx, value)` where `value`
+            is the label for indice `idx`.
+        """
+        has_label_attr = hasattr(self._dataset, 'label')
+        if has_label_attr:
+            if callable(self._dataset.label):
+                return True
+            else:
+                warnings.warn('Dataset has an attribute `label`, but it is not callable.'
+                              'The Dataset will not be labelled with new labels.',
+                              UserWarning)
+        return False
+
     def __getitem__(self, index: int) -> Tuple[torch.Tensor, ...]:
         """Return stuff from the original dataset."""
         return self._dataset[self._labelled_to_oracle_index(index)]
@@ -172,7 +193,7 @@ class ActiveLearningDataset(torchdata.Dataset):
                 self._labelled[index] = 1
                 if val is not None:
                     warnings.warn(
-                        "We will consider the original label of this datasample : {}.".format(
+                        "We will consider the original label of this datasample : {}, {}.".format(
                             self._dataset[index][0], self._dataset[index][1]), UserWarning)
 
     def label_randomly(self, n: int = 1) -> None:
