@@ -111,6 +111,7 @@ class AbstractHeuristic:
         self.shuffle_prop = shuffle_prop
         self.reversed = reverse
         assert reduction in available_reductions or callable(reduction)
+        self._reduction_name = reduction
         self.reduction = reduction if callable(reduction) else available_reductions[reduction]
 
     def compute_score(self, predictions):
@@ -176,11 +177,19 @@ class AbstractHeuristic:
 
         Returns:
             ordered index according to the uncertainty (highest to lowes).
+
+        Raises:
+            ValueError if `scores` is not uni-dimensional.
         """
         if isinstance(scores, Sequence):
             scores = np.concatenate(scores)
-        assert scores.ndim <= 2
-        ranks = np.argsort(scores, -1)
+
+        if scores.ndim > 1:
+            raise ValueError((f"Can't order sequence with more than 1 dimension."
+                              f"Currently {scores.ndim} dimensions."
+                              f"Is the heuristic reduction method set: {self._reduction_name}"))
+        assert scores.ndim == 1  # We want the uncertainty value per sample.
+        ranks = np.argsort(scores)
         if self.reversed:
             ranks = ranks[::-1]
         ranks = _shuffle_subset(ranks, self.shuffle_prop)
@@ -344,12 +353,15 @@ class BatchBALD(BALD):
         """
         Compute the joint entropy between `preditions` and `selected`
         Args:
-            predictions (Tensor): First tensor with shape [B, C, ..., Iterations]
+            predictions (Tensor): First tensor with shape [B, C, Iterations]
             selected (Tensor): Second tensor with shape [M, Iterations].
 
         References:
             Code from https://github.com/BlackHC/BatchBALD/blob/master/src/joint_entropy/sampling.py
 
+        Notes:
+            Only Classification is supported, not semantic segmentation or other.
+
         Returns:
             Generator yield B entropies.
         """
@@ -376,7 +388,10 @@ class BatchBALD(BALD):
         Compute the score according to the heuristic.
 
         Args:
-            predictions (ndarray): Array of predictions
+            predictions (ndarray): Array of predictions [batch_size, C, Iterations]
+
+        Notes:
+            Only Classification is supported, not semantic segmentation or other.
 
         Returns:
             Array of scores.
@@ -428,17 +443,24 @@ class BatchBALD(BALD):
         Rank the predictions according to their uncertainties.
 
         Args:
-            predictions (ndarray): [batch_size, C, ..., Iterations]
+            predictions (ndarray): [batch_size, C, Iterations]
 
         Returns:
             Ranked index according to the uncertainty (highest to lowest).
 
+        Notes:
+            Only Classification is supported, not semantic segmentation or other.
+
         Raises:
             ValueError if predictions is a generator.
         """
         if isinstance(predictions, types.GeneratorType):
             raise ValueError("BatchBALD doesn't support generators.")
 
+        if predictions.ndim != 3:
+            raise ValueError("BatchBALD only works on classification"
+                             "Expected shape= [batch_size, C, Iterations]")
+
         ranks = self.get_uncertainties(predictions)
 
         assert ranks.ndim == 1
@@ -576,7 +598,7 @@ class Random(Precomputed):
 
     def get_ranks(self, predictions):
         if isinstance(predictions, types.GeneratorType):
-            predictions = np.array([1 for _ in predictions])
+            predictions = np.array([np.ones([t.shape[0]]) for t in predictions]).reshape([-1])
         return self.reorder_indices(predictions)
 
 
