@@ -1,4 +1,5 @@
 import copy
+import warnings
 
 import torch
 from torch.nn import functional as F
@@ -90,6 +91,9 @@ def patch_module(module: torch.nn.Module, inplace: bool = True) -> torch.nn.Modu
         inplace (bool, optional):
             Whether to modify the module in place or return a copy of the module.
 
+    Raises:
+        UserWarning if no layer is modified.
+
     Returns:
         torch.nn.Module
             The modified module, which is either the same object as you passed in
@@ -97,16 +101,21 @@ def patch_module(module: torch.nn.Module, inplace: bool = True) -> torch.nn.Modu
     """
     if not inplace:
         module = copy.deepcopy(module)
-    _patch_dropout_layers(module)
+    changed = _patch_dropout_layers(module)
+    if not changed:
+        warnings.warn('No layer was modified by patch_module!', UserWarning)
     return module
 
 
-def _patch_dropout_layers(module: torch.nn.Module) -> None:
+def _patch_dropout_layers(module: torch.nn.Module) -> bool:
     """
     Recursively iterate over the children of a module and replace them if
     they are a dropout layer. This function operates in-place.
-    """
 
+    Returns:
+        Flag indicating if a layer was modified.
+    """
+    changed = False
     for name, child in module.named_children():
         if isinstance(child, torch.nn.Dropout):
             new_module = Dropout(p=child.p, inplace=child.inplace)
@@ -116,10 +125,12 @@ def _patch_dropout_layers(module: torch.nn.Module) -> None:
             new_module = None
 
         if new_module is not None:
+            changed = True
             module.add_module(name, new_module)
 
         # recursively apply to child
-        _patch_dropout_layers(child)
+        changed = changed or _patch_dropout_layers(child)
+    return changed
 
 
 class MCDropoutModule(torch.nn.Module):
